==> chaosmesh-model-5.0.1-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/NetworkChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface NetworkChaosStatusFluent<A extends NetworkChaosStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildExperiment instead.
 * @return The buildable object.
 */
@Deprecated public ExperimentStatus getExperiment();
    public ExperimentStatus buildExperiment();
    public A withExperiment(ExperimentStatus experiment);
    public Boolean hasExperiment();
    public NetworkChaosStatusFluent.ExperimentNested<A> withNewExperiment();
    public NetworkChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
    public NetworkChaosStatusFluent.ExperimentNested<A> editExperiment();
    public NetworkChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
    public NetworkChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
    public String getFailedMessage();
    public A withFailedMessage(String failedMessage);
    public Boolean hasFailedMessage();
    public A withNewFailedMessage(String arg1);
    public A withNewFailedMessage(StringBuilder arg1);
    public A withNewFailedMessage(StringBuffer arg1);
    public String getPhase();
    public A withPhase(String phase);
    public Boolean hasPhase();
    public A withNewPhase(String arg1);
    public A withNewPhase(StringBuilder arg1);
    public A withNewPhase(StringBuffer arg1);
    public String getReason();
    public A withReason(String reason);
    public Boolean hasReason();
    public A withNewReason(String arg1);
    public A withNewReason(StringBuilder arg1);
    public A withNewReason(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public ScheduleStatus getScheduler();
    public ScheduleStatus buildScheduler();
    public A withScheduler(ScheduleStatus scheduler);
    public Boolean hasScheduler();
    public A withNewScheduler(String nextRecover,String nextStart);
    public NetworkChaosStatusFluent.SchedulerNested<A> withNewScheduler();
    public NetworkChaosStatusFluent.SchedulerNested<A> withNewSchedulerLike(ScheduleStatus item);
    public NetworkChaosStatusFluent.SchedulerNested<A> editScheduler();
    public NetworkChaosStatusFluent.SchedulerNested<A> editOrNewScheduler();
    public NetworkChaosStatusFluent.SchedulerNested<A> editOrNewSchedulerLike(ScheduleStatus item);
    public interface ExperimentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExperimentStatusFluent<NetworkChaosStatusFluent.ExperimentNested<N>> {

            public N and();
            public N endExperiment();    }


    public interface SchedulerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ScheduleStatusFluent<NetworkChaosStatusFluent.SchedulerNested<N>> {

            public N and();
            public N endScheduler();    }


}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/NetworkChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface NetworkChaosStatusFluent<A extends NetworkChaosStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildExperiment instead.
 * @return The buildable object.
 */
@Deprecated public ExperimentStatus getExperiment();
    public ExperimentStatus buildExperiment();
    public A withExperiment(ExperimentStatus experiment);
    public Boolean hasExperiment();
    public NetworkChaosStatusFluent.ExperimentNested<A> withNewExperiment();
    public NetworkChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
    public NetworkChaosStatusFluent.ExperimentNested<A> editExperiment();
    public NetworkChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
    public NetworkChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
    public String getFailedMessage();
    public A withFailedMessage(String failedMessage);
    public Boolean hasFailedMessage();
    public A withNewFailedMessage(StringBuilder arg1);
    public A withNewFailedMessage(int[] arg1,int arg2,int arg3);
    public A withNewFailedMessage(char[] arg1);
    public A withNewFailedMessage(StringBuffer arg1);
    public A withNewFailedMessage(byte[] arg1,int arg2);
    public A withNewFailedMessage(byte[] arg1);
    public A withNewFailedMessage(char[] arg1,int arg2,int arg3);
    public A withNewFailedMessage(byte[] arg1,int arg2,int arg3);
    public A withNewFailedMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFailedMessage(String arg1);
    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public ScheduleStatus getScheduler();
    public ScheduleStatus buildScheduler();
    public A withScheduler(ScheduleStatus scheduler);
    public Boolean hasScheduler();
    public A withNewScheduler(String nextRecover,String nextStart);
    public NetworkChaosStatusFluent.SchedulerNested<A> withNewScheduler();
    public NetworkChaosStatusFluent.SchedulerNested<A> withNewSchedulerLike(ScheduleStatus item);
    public NetworkChaosStatusFluent.SchedulerNested<A> editScheduler();
    public NetworkChaosStatusFluent.SchedulerNested<A> editOrNewScheduler();
    public NetworkChaosStatusFluent.SchedulerNested<A> editOrNewSchedulerLike(ScheduleStatus item);
    public interface ExperimentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExperimentStatusFluent<NetworkChaosStatusFluent.ExperimentNested<N>> {

            public N and();
            public N endExperiment();    }


    public interface SchedulerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ScheduleStatusFluent<NetworkChaosStatusFluent.SchedulerNested<N>> {

            public N and();
            public N endScheduler();    }


}
